package com.urbancode.air.plugin.udeploy.components

import com.urbancode.air.AirPluginTool
import com.urbancode.ud.client.UDRestClient
import java.util.UUID

public class ComponentHelper {
    def apTool
    def props = []
    def udUser
    def udPass
    def weburl
    UDRestClient client
    
    public ComponentHelper(def apToolIn) {
        apTool = apToolIn
        props = apTool.getStepProperties()
        udUser = apTool.getAuthTokenUsername()
        udPass = apTool.getAuthToken()
        weburl = System.getenv("AH_WEB_URL")
        client = new UDRestClient(new URI(weburl), udUser, udPass)
        
        com.urbancode.air.XTrustProvider.install()
    }
    
    public def createComponent() {
        def compName = props['component']
        def description = props['description']
        def templateName = props['template']
        def templateVersion
        def sourceConfigType = props['sourceConfig']
        def defaultVersionType = props['defaultVersionType']
        def importAutomatically = Boolean.valueOf(props['importAutomatically'])
        def useVfs = Boolean.valueOf(props['useVfs'])
        
        if (!compName) {
            throw new IllegalArgumentException("no component name was specified")
        }
        if (!defaultVersionType) {
            throw new IllegalArgumentException("no version type was specified")
        }
        if (!description) {
            description = ""
        }
        if (!templateName) {
            templateName = ""
        }
        try {
            templateVersion = Integer.valueOf(props['templateVersion'])
        }
        catch(NumberFormatException e) {
            templateVersion = 0
        }
        
        UUID compUUID = client.createComponent(compName, description, sourceConfigType, 
            defaultVersionType, templateName, templateVersion, importAutomatically, useVfs)
        apTool.setOutputProperty("component.id", compUUID.toString())
        apTool.setOutputProperties()
    }
    
    public def setComponentProperty() {
        def componentName = props['component']
        def propName = props['name']
        def propValue = props['value']
        def isSecure = Boolean.valueOf(props['isSecure'])
        
        if (!propName) {
            throw new IllegalArgumentException("no property name was specified")
        }
        if (!propValue) {
            propValue = ""
        }
        if (!componentName) {
            throw new IllegalArgumentException("no component was specified")
        }
        client.setComponentProperty(componentName, propName, propValue, isSecure)
    }
    
    public def createComponentRole() {
        def roleName = props['role']
        
        if (!roleName) {
            throw new IllegalArgumentException("no component was specified")
        }
        
        UUID roleUUID = client.createComponentRole(roleName)
        println "component role created with name: " + roleName
        apTool.setOutputProperty("component.role.id", roleUUID.toString())
        apTool.setOutputProperties()
    }
    
}